@@ -153,6 +153,8 @@ SM_DRAW_GRADIENT = 512
 SM_DRAW_FANCY_TICKS = 1024
 SM_DRAW_TITLE_TEXT = 2048
 SM_DRAW_SUB_TEXT = 4096
+SM_DRAW_SUB2_TEXT = 8192
+
 
 #----------------------------------------------------------------------
 # Event Binding
@@ -391,6 +393,7 @@ class SpeedMeter(BufferedWindow):
 
         self.SetTitleText()
         self.SetSubText()
+        self.SetSub2Text()
 
         
         BufferedWindow.__init__(self, parent, id, pos, size,
@@ -927,10 +930,26 @@ class SpeedMeter(BufferedWindow):
 
             mw, mh, dummy, dummy = dc.GetFullTextExtent(titletext, middlefont)
             
+            dc.SetTextForeground(middlecolour)
+            dc.DrawText(subtext, 0, 115)
+
+        if self._extrastyle & SM_DRAW_SUB2_TEXT:
+
+            middlecolour = self.GetMiddleTextColour()            
+            subtext = self.GetSub2Text()
+            #middleangle = (startangle + endangle)/2.0
+            
+            middlefont, middlesize = self.GetMiddleTextFont()
+            middlesize = self.scale*middlesize*0.7
+            middlefont.SetPointSize(int(middlesize))
+            dc.SetFont(middlefont)
+
+            mw, mh, dummy, dummy = dc.GetFullTextExtent(titletext, middlefont)
+            
             #newx = centerX + 1.5*mw*cos(middleangle) - mw/2.0
             #newy = centerY - 1.5*mh*sin(middleangle) - mh/2.0
             dc.SetTextForeground(middlecolour)
-            dc.DrawText(subtext, 0, 120)
+            dc.DrawText(subtext, 0, 230)
 
 
         # Here We Draw The Icon In The Middle, Near The Start Of The Arrow (If Present)
@@ -1352,6 +1371,13 @@ class SpeedMeter(BufferedWindow):
 
         self._subtext = text
 
+    def SetSub2Text(self, text=None):
+        
+        if text is None:
+            text = ""
+
+        self._sub2text = text
+
     def GetMiddleText(self):
         """ Gets The Text To Be Drawn Near The Center Of SpeedMeter. """
         
@@ -1365,6 +1391,9 @@ class SpeedMeter(BufferedWindow):
         
         return self._subtext
 
+    def GetSub2Text(self):
+        
+        return self._sub2text
 
 
     def SetMiddleTextFont(self, font=None):
