@@ -42,32 +42,29 @@ from debugEvent import *
 #__________________________________________________________________________
 def decrypt_dtc_code(code):
     """Returns the 5-digit DTC code from hex encoding"""
-    dtc = []
-    current = code
-    for i in range(0,3):
-        if len(current)<4:
-            raise "Tried to decode bad DTC: %s" % code
+    dtc = ""
+    if len(code)<4:
+        raise "Tried to decode bad DTC: %s" % code
 
-        tc = obd_sensors.hex_to_int(current[0]) #typecode
-        tc = tc >> 2
-        if   tc == 0:
-            type = "P"
-        elif tc == 1:
-            type = "C"
-        elif tc == 2:
-            type = "B"
-        elif tc == 3:
-            type = "U"
-        else:
-            raise tc
+    tc = obd_sensors.hex_to_int(code[0]) #typecode
+    tc = tc >> 2
+    if   tc == 0:
+        type = "P"
+    elif tc == 1:
+        type = "C"
+    elif tc == 2:
+        type = "B"
+    elif tc == 3:
+        type = "U"
+    else:
+        raise tc
 
-        dig1 = str(obd_sensors.hex_to_int(current[0]) & 3)
-        dig2 = str(obd_sensors.hex_to_int(current[1]))
-        dig3 = str(obd_sensors.hex_to_int(current[2]))
-        dig4 = str(obd_sensors.hex_to_int(current[3]))
+    dig1 = str(obd_sensors.hex_to_int(code[0]) & 3)
+    dig2 = str(obd_sensors.hex_to_int(code[1]))
+    dig3 = str(obd_sensors.hex_to_int(code[2]))
+    dig4 = str(obd_sensors.hex_to_int(code[3]))
 
-        dtc.append(type+dig1+dig2+dig3+dig4)
-        current = current[4:]
+    dtc = type+dig1+dig2+dig3+dig4
     return dtc
 #__________________________________________________________________________
 
@@ -108,8 +105,10 @@ class OBDPort:
              except serial.SerialException:
                 self.State = 0
 #mmmm                
-             print self.get_result()
-             self.ELMver = self.get_result()
+             print "1 response "+self.get_result()
+             response=self.get_result()
+             print "2 response "+response
+             self.ELMver = response
 
              wx.PostEvent(self._notify_window, DebugEvent([2,"atz response:" + self.ELMver]))
              print "self.state: "+str(self.State)
@@ -183,11 +182,13 @@ class OBDPort:
      def send_command(self, cmd):
          """Internal use only: not a public interface"""
          if self.port:
-             time.sleep(0.1)
+             time.sleep(0.05)
              self.port.flushOutput()
              self.port.flushInput()
+             time.sleep(0.01)
              for c in cmd:
                  self.port.write(c)
+                 time.sleep(0.01)
              self.port.write("\r\n")
              time.sleep(0.1)
              wx.PostEvent(self._notify_window, DebugEvent([3,"Send command:" + cmd]))
@@ -226,16 +227,16 @@ class OBDPort:
     
      def get_result(self):
          """Internal use only: not a public interface"""
-         time.sleep(0.2)
+         time.sleep(0.5)
          if self.port:
              buffer = ""
              while 1:
                  c = self.port.read(1)
-                 if c == '\r' and len(buffer) > 0:
+                 if (c in ['\r', '\n']) and len(buffer) > 0:
                      break
                  else:
-                     if buffer != "" or c != ">": #if something is in buffer, add everything
-                      buffer = buffer + c
+                     if c != "" and c != ">" and c != "?" and not (c in ['\r', '\n']):
+                         buffer = buffer + c             
              wx.PostEvent(self._notify_window, DebugEvent([3,"Get result:" + buffer]))
              return buffer
          else:
@@ -305,7 +306,7 @@ class OBDPort:
           print "get_dtc"
           """Returns a list of all pending DTC codes. Each element consists of
           a 2-tuple: (DTC code (string), Code description (string) )"""
-          dtcLetters = ["P", "C", "B", "U"]
+          #dtcLetters = ["P", "C", "B", "U"]
           r = self.sensor(1)[1] #data
           dtcNumber = r[0]
           mil = r[1]
@@ -319,15 +320,11 @@ class OBDPort:
             res = self.get_result()
             print "DTC result:" + res
             for i in range(0, 3):
-                val1 = hex_to_int(res[3+i*6:5+i*6])
-                val2 = hex_to_int(res[6+i*6:8+i*6]) #get DTC codes from response (3 DTC each 2 bytes)
-                val  = (val1<<8)+val2 #DTC val as int
-                
-                if val==0: #skip fill of last packet
+                DTC_raw = res[3+i*6:5+i*6] + res[6+i*6:8+i*6]
+                if DTC_raw=="0000": #skip fill of last packet
                   break
-                   
-                DTCStr=dtcLetters[(val&0xC000)>14]+str((val&0x3000)>>12)+str(val&0x0fff) 
-                
+                  
+                DTCStr = decrypt_dtc_code(DTC_raw)
                 DTCCodes.append(["Active",DTCStr])
           
           #read mode 7
@@ -339,14 +336,11 @@ class OBDPort:
           
           print "DTC freeze result:" + res
           for i in range(0, 3):
-              val1 = hex_to_int(res[3+i*6:5+i*6])
-              val2 = hex_to_int(res[6+i*6:8+i*6]) #get DTC codes from response (3 DTC each 2 bytes)
-              val  = (val1<<8)+val2 #DTC val as int
-                
-              if val==0: #skip fill of last packet
+              DTC_raw = res[3+i*6:5+i*6] + res[6+i*6:8+i*6]
+              if DTC_raw=="0000": #skip fill of last packet
                 break
-                   
-              DTCStr=dtcLetters[(val&0xC000)>14]+str((val&0x3000)>>12)+str(val&0x0fff)
+                  
+              DTCStr = decrypt_dtc_code(DTC_raw)
 
               #M se restituisce codici a 6 cifre invece che ha 5
               if len(DTCStr)>5:
